@@ -1,10 +1,10 @@
 /*
     orzpref
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,21 +13,11 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "orzpref.h"
 #include "orzhistory.h"
 #include "misc/misc.h"
-#include <gdk/gdkkeysyms.h>
-
-
-static void orz_pref_class_init (OrzPrefClass *klass);
-static void orz_pref_init       (OrzPref      *dialog);
-static void orz_pref_escape     (OrzPref      *dialog);
-
-
-static GtkDialogClass *parent_class = NULL;
 
 
 enum
@@ -43,47 +33,15 @@ static gint orz_pref_signals[LAST_SIGNAL] = {0};
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GtkType
-orz_pref_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    {
-      const static GTypeInfo info =
-      {
-        sizeof (OrzPrefClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)orz_pref_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (OrzPref),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc)orz_pref_init,
-      };
-
-      type = g_type_register_static (GTK_TYPE_DIALOG, "OrzPref", &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (OrzPref, orz_pref, GTK_TYPE_DIALOG);
+static void orz_pref_escape (OrzPref *pref);
 
 
 static void
 orz_pref_class_init (OrzPrefClass *klass)
 {
-  GObjectClass *gobject_class;
-  GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
   GtkBindingSet *binding_set;
 
-  gobject_class = (GObjectClass *)klass;
-  object_class = (GtkObjectClass *)klass;
-  widget_class = (GtkWidgetClass *)klass;
-
-  parent_class = g_type_class_peek_parent (klass);
-
   klass->escape = orz_pref_escape;
 
   orz_pref_signals[ESCAPE_SIGNAL]
@@ -96,7 +54,7 @@ orz_pref_class_init (OrzPrefClass *klass)
                                 G_TYPE_NONE, 0);
 
   binding_set = gtk_binding_set_by_class (klass);
-  gtk_binding_entry_add_signal (binding_set, GDK_Escape, 0, "escape", 0);
+  gtk_binding_entry_add_signal (binding_set, GDK_KEY_Escape, 0, "escape", 0);
 }
 
 
@@ -115,8 +73,8 @@ static void
 orz_pref_activate (GtkWidget *widget,
                    OrzPref   *pref)
 {
-  if (GTK_WIDGET_VISIBLE (pref->ok_button)
-                                    && GTK_WIDGET_SENSITIVE (pref->ok_button))
+  if (gtk_widget_get_visible (pref->ok_button)
+                                && gtk_widget_get_sensitive (pref->ok_button))
     g_signal_emit_by_name (G_OBJECT (pref->ok_button), "clicked");
 }
 
@@ -124,8 +82,8 @@ orz_pref_activate (GtkWidget *widget,
 static void
 orz_pref_escape (OrzPref *pref)
 {
-  if (GTK_WIDGET_VISIBLE (pref->cancel_button)
-                                && GTK_WIDGET_SENSITIVE (pref->cancel_button))
+  if (gtk_widget_get_visible (pref->cancel_button)
+                            && gtk_widget_get_sensitive (pref->cancel_button))
     g_signal_emit_by_name (G_OBJECT (pref->cancel_button), "clicked");
 }
 
@@ -136,8 +94,8 @@ orz_pref_delete (GtkWidget *widget,
                  GdkEvent  *event,
                  gpointer   user_data)
 {
-  if (GTK_WIDGET_VISIBLE (ORZ_PREF (widget)->cancel_button)
-                    && GTK_WIDGET_SENSITIVE (ORZ_PREF (widget)->cancel_button))
+  if (gtk_widget_get_visible (ORZ_PREF (widget)->cancel_button)
+                && gtk_widget_get_sensitive (ORZ_PREF (widget)->cancel_button))
     g_signal_emit_by_name
                     (G_OBJECT (ORZ_PREF (widget)->cancel_button), "clicked");
   return TRUE;
@@ -271,10 +229,9 @@ orz_pref_init (OrzPref *pref)
   gtk_box_pack_start (GTK_BOX (hbox0), vbox, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox0), frame1, TRUE, TRUE, 0);
 
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (pref));
+  gtk_box_set_spacing (GTK_BOX (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), hbox0, TRUE, TRUE, 0);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (pref)->vbox), vbox);
 
   /* ja:表示 */
   gtk_dialog_set_response_sensitive (GTK_DIALOG (pref),
@@ -372,7 +329,7 @@ orz_pref_set_history (OrzPref    *pref,
 {
   gboolean sensitive;
 
-  sensitive = GTK_WIDGET_SENSITIVE (pref->ok_button);
+  sensitive = gtk_widget_get_sensitive (pref->ok_button);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (pref->history_spin), history);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (pref), GTK_RESPONSE_OK,
                                                                     sensitive);
@@ -388,7 +345,7 @@ orz_pref_set_newfile (OrzPref        *pref,
 {
   gboolean sensitive;
 
-  sensitive = GTK_WIDGET_SENSITIVE (pref->ok_button);
+  sensitive = gtk_widget_get_sensitive (pref->ok_button);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pref->newfile_check),
                                                                     newfile);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (pref), GTK_RESPONSE_OK,
@@ -405,7 +362,7 @@ orz_pref_set_second (OrzPref        *pref,
 {
   gboolean sensitive;
 
-  sensitive = GTK_WIDGET_SENSITIVE (pref->ok_button);
+  sensitive = gtk_widget_get_sensitive (pref->ok_button);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pref->second_check),
                                                                     second);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (pref), GTK_RESPONSE_OK,
@@ -424,7 +381,7 @@ orz_pref_set_size (OrzPref    *pref,
 {
   gboolean sensitive;
 
-  sensitive = GTK_WIDGET_SENSITIVE (pref->ok_button);
+  sensitive = gtk_widget_get_sensitive (pref->ok_button);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (pref->width_spin), width);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (pref->height_spin), height);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (pref), GTK_RESPONSE_OK,
@@ -441,7 +398,7 @@ orz_pref_set_tab (OrzPref               *pref,
 {
   gboolean sensitive;
 
-  sensitive = GTK_WIDGET_SENSITIVE (pref->ok_button);
+  sensitive = gtk_widget_get_sensitive (pref->ok_button);
   switch (n_pos)
     {
       case GTK_POS_TOP:
